@@ -1,5 +1,8 @@
+from operator import itemgetter
+
 import jwt
 import pytest
+import sys
 import uuid
 from stream_chat import StreamChat
 from stream_chat.exceptions import StreamAPIException
@@ -7,6 +10,27 @@ from stream_chat.exceptions import StreamAPIException
 
 @pytest.mark.incremental
 class TestClient(object):
+    def test_normalize_sort(self, client):
+        expected = [
+            {"field": "field1", "direction": 1},
+            {"field": "field2", "direction": -1},
+        ]
+        actual = client.normalize_sort([{"field1": 1}, {"field2": -1}])
+        assert actual == expected
+        actual = client.normalize_sort(
+            [{"field": "field1", "direction": 1}, {"field": "field2", "direction": -1}]
+        )
+        assert actual == expected
+        actual = client.normalize_sort({"field1": 1})
+        assert actual == [{"field": "field1", "direction": 1}]
+        # The following example is not recommended because the order of the fields is not guaranteed in Python < 3.7
+        actual = client.normalize_sort({"field1": 1, "field2": -1})
+        if sys.version_info >= (3, 7):
+            assert actual == expected
+        else:
+            # Compare elements regardless of the order
+            assert sorted(actual, key=itemgetter("field")) == expected
+
     def test_mute_user(self, client, random_users):
         response = client.mute_user(random_users[0]["id"], random_users[1]["id"])
         assert "mute" in response
@@ -61,11 +85,6 @@ class TestClient(object):
         assert "command" in response
         assert "My new command" == response["command"]["description"]
 
-    def test_delete_command(self, client, command):
-        response = client.delete_command(command["name"])
-        with pytest.raises(StreamAPIException):
-            client.get_command(command["name"])
-
     def test_list_commands(self, client):
         response = client.list_commands()
         assert "commands" in response
@@ -223,3 +242,25 @@ class TestClient(object):
         assert len(response["channels"]) == 1
         assert response["channels"][0]["channel"]["id"] == "fellowship-of-the-ring"
         assert len(response["channels"][0]["members"]) == 9
+
+    def test_create_blocklist(self, client):
+        response = client.create_blocklist(name="Foo", words=["fudge", "heck"])
+
+    def test_list_blocklists(self, client):
+        response = client.list_blocklists()
+        assert len(response["blocklists"]) == 2
+        blocklist_names = {blocklist["name"] for blocklist in response["blocklists"]}
+        assert "Foo" in blocklist_names
+
+    def test_get_blocklist(self, client):
+        response = client.get_blocklist("Foo")
+        assert response["blocklist"]["name"] == "Foo"
+        assert response["blocklist"]["words"] == ["fudge", "heck"]
+
+    def test_update_blocklist(self, client):
+        client.update_blocklist("Foo", words=["dang"])
+        response = client.get_blocklist("Foo")
+        assert response["blocklist"]["words"] == ["dang"]
+
+    def test_delete_blocklist(self, client):
+        client.delete_blocklist("Foo")
